/*
 * Finger.m
 * 2/9/99 Mike Trent
 * mtrent@msn.fullfeed.com
 *
 * Our finger window controller. This is the *REAL* main controller object for
 * our App. It coordinates with everything else to actually fulfill the finger
 * request.
 */

#import "Finger.h"
#import "TextWindow.h"

// Store our NSImages statically; I feel bad about asking for multiple
// copies of graphic resources ... 
static NSImage *gPattern = nil;
static NSImage *gIcon = nil;

@implementation Finger

//
// Initialization
//

- (id)init
{
    self = [super initWithWindowNibName:@"Finger" owner:self];

    if (!gPattern) gPattern = [[NSImage imageNamed:@"pattern"] retain];
    if (!gIcon) gIcon = [[NSImage imageNamed:@"icon.tiff"] retain];

    return self;
}

- (void)dealloc
{
    [panel1 release];
    [panel2 release];

    [_tool release];
    [_target release];
    
    [super dealloc];
}

- (void)windowDidLoad
{
    [super windowDidLoad];

    // retain our views so they sticks around
    [panel1 retain];
    [panel2 retain];
    
    [userField setStringValue:@""];
    [machineField setStringValue:@""];
    [tiledImageView1 setImage:gPattern];

    [(NSBox*)mainView setContentView:panel1];

    // because we're schlepping subviews around, we need to manage our
    // tab chain by brute force.
    [[self window] setInitialFirstResponder:userField];
    [[self window] makeFirstResponder:userField];
    [[self window] setMiniwindowImage:gIcon];
    [userField setNextKeyView:machineField];
    [machineField setNextKeyView:userField];
}

//
// User Interface Code
//

- (void)update
{
    // finger is only clickable when the text fields are non-empty.to allow 
    // finger to be clickable always, just setEnabled:YES below.
    [fingerBtn setEnabled:([[userField stringValue] length] || [[machineField stringValue] length])];
}

//- (void)windowWillClose:(NSNotification *)aNotification
- (void)windowDidClose:(NSNotification *)aNotification
{
    [self autorelease];
}

- (void)cancel:(id)sender
{
    [self close];
}

- (void)finger:(id)sender
{
    NSArray *args = nil;

    // build the target string
    if (!([[userField stringValue] length] || [[machineField stringValue] length])) {
        _target = nil;
    } else if ([[machineField stringValue] length]) {
        _target = [NSString stringWithFormat:@"%@@%@",
            [userField stringValue],
            [machineField stringValue]];
    } else {
        _target = [userField stringValue];
    }
    if (_target) [_target retain];
    
    // set our finger panel UI
    [tiledImageView2 setImage:gPattern];
    [progressBar setIndeterminate:YES];
    [progressBar startAnimation:sender];
    [(NSBox*)mainView setContentView:panel2];
    if (_target) {
        [fingerField setStringValue:_target];
    } else {
        [fingerField setStringValue:@""];
    }

    // kick off our command
    _tool = [[ToolRunner alloc] init];
    if (_target) args = [NSArray arrayWithObject:_target];
    [_tool run:@"/usr/bin/finger" arguments:args delegate:self];
}

- (void)toolDidTerminate:(int)status
{
    NSString *s = [_tool output];
    TextWindow *tw = [[TextWindow alloc] init];

    if (status) NSLog(@"finger returned a non-zero status: %d", status);

    // spawn off a text window
    [tw showWindow:NSWindowAbove relativeTo:[self window]];
    [tw setText:s];
    if (_target) [tw setTitle:_target];

    // go home
    [self close];
}

@end
