/*
 * FingerWindow.m
 * 2/9/99 Mike Trent
 * mtrent@msn.fullfeed.com
 *
 * This NSWindow subclass allows us to dim the 'Finger' button when the user
 * hasn't typed enough information to make a complete finger request. In essense
 * it just forwards the window's update event on to the delegate. I have used a
 * slightly more complex version of this subclass to support toolbars and such,
 * but I think this more general approach is better: it allows the delegate to
 * decide how to handle the update event.
 */

#import "FingerWindow.h"

@interface UpdatableObject
- (void)update;
@end

@implementation FingerWindow

- (void)update
{
    NSObject *delegate = [self delegate];

    if ([delegate respondsToSelector:@selector(update)]) {
        [(UpdatableObject*)delegate update];
    }

    [super update];
}
@end
