/*
 * TextWindow.m
 * 2/9/99 Mike Trent
 * mtrent@msn.fullfeed.com
 *
 * A simple class for displaying and printing read-only mono-spaced text
 * windows. Not quite fleshed out enough for text entry...
 */

#import "TextWindow.h"
#import "TabStopStrategy.h"

// Store our NSImages statically; I feel bad about asking for multiple
// copies of graphic resources ... 
static NSImage *gIcon = nil;

@implementation TextWindow

- (id)init
{
    self = [super initWithWindowNibName:@"TextWindow" owner:self];

    if (!gIcon) gIcon = [[NSImage imageNamed:@"text.tiff"] retain];

    return self;
}

- (void)setText:(NSString*)string
{
    if (!textView) [self showWindow:self];
    [textView setString:string];
    [[TabStopStrategy strategy] fixTabStopsInView:textView];
}

- (void)setTitle:(NSString*)title
{
    [[self window] setTitle:title];
}

- (void)windowWillClose:(NSNotification *)aNotification
{
    [self autorelease];
}

- (void)saveDocument:(id)sender
{
    NSSavePanel *sp;
    int runResult;
    
    sp = [NSSavePanel savePanel];
    [sp setRequiredFileType:@"txt"];
    
    runResult = [sp runModal];

    if (runResult == NSOKButton) {
        if (![[textView string] writeToFile:[sp filename] atomically:YES])
            NSBeep();
    }
}

// this can be called in place of showWindow:. 
- (void)showWindow:(NSWindowOrderingMode)mode relativeTo:(NSWindow*)w
{
    [[self window] orderWindow:mode relativeTo:[w windowNumber]];
}

/*
 * Even though this isn't a Document-based application, the print menu item is 
 * wired to printDocument:. This lets us receive the signal without the window
 * or the textView intercepting the command and doing the wrong thing.
 */
- (void)printDocument:(id)sender {
    NSPrintInfo *printInfo = [[NSPrintInfo sharedPrintInfo] copy];
    NSTextView *view;
    NSRect bounds = [textView bounds];
    NSWindow *window = [[NSWindow allocWithZone:[self zone]] initWithContentRect:NSMakeRect(0.0, 0.0, NSMaxX(bounds), NSMaxY(bounds)) styleMask:NSBorderlessWindowMask backing:NSBackingStoreNonretained defer:NO];

    // set up a separate text view so we can print on a white background
    view = [[NSTextView alloc] initWithFrame:[textView frame]];
    [view setString:[textView string]];
    [view setFont:[textView font]];
    [[TabStopStrategy strategy] fixTabStopsInView:view];
    [[window contentView] addSubview:view];

    // do the print operation
    [printInfo setHorizontalPagination:NSFitPagination];
    [printInfo setHorizontallyCentered:NO];
    [printInfo setVerticallyCentered:NO];
    [[NSPrintOperation printOperationWithView:view printInfo:printInfo] runOperation];
    [printInfo release];

    // release our window and view
    [window release];
    [view release];
}

- (void)windowDidLoad
{
    [super windowDidLoad];

    [[self window] setMiniwindowImage:gIcon];
}

@end
